from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Driver_LED = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'AL8860MP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AL8860MP'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8-1EP_3x3mm_P0.65mm_EP1.5x1.8mm'], 'footprint':'Package_SO:MSOP-8-1EP_3x3mm_P0.65mm_EP1.5x1.8mm', 'keywords':'LED Driver Buck Constant Current', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/AL8860.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nAL8860MP\n\nLED Driver Buck Constant Current', 'pins':[
            Pin(num='1',name='SET',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SW',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='SW',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AL8860WT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AL8860WT'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-5'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-5', 'keywords':'LED Driver Buck Constant Current', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/AL8860.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nAL8860WT\n\nLED Driver Buck Constant Current', 'pins':[
            Pin(num='1',name='SW',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SET',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VIN',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BCR430UW6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BCR430UW6'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SC-74-6_1.55x2.9mm_P0.95mm'], 'footprint':'Package_TO_SOT_SMD:SC-74-6_1.55x2.9mm_P0.95mm', 'keywords':'LED driver constant current', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/BCR430UW6.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nBCR430UW6\n\nLED driver constant current', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='REXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='OUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CH455G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH455G'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOP-16_3.9x9.9mm_P1.27mm', 'keywords':'WCH Nixie I2C', 'description':'', 'datasheet':'https://www.wch-ic.com/products/CH455.html', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nCH455G\n\nWCH Nixie I2C', 'pins':[
            Pin(num='1',name='SEG4',func=pin_types.TRISTATE),
            Pin(num='10',name='DIG2',func=pin_types.OUTPUT),
            Pin(num='11',name='DIG3',func=pin_types.OUTPUT),
            Pin(num='12',name='SEG0',func=pin_types.TRISTATE),
            Pin(num='13',name='SEG1',func=pin_types.TRISTATE),
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='15',name='SEG2',func=pin_types.TRISTATE),
            Pin(num='16',name='SEG3',func=pin_types.TRISTATE),
            Pin(num='2',name='SEG5',func=pin_types.TRISTATE),
            Pin(num='3',name='SEG6',func=pin_types.TRISTATE),
            Pin(num='4',name='SEG7',func=pin_types.TRISTATE),
            Pin(num='5',name='DIG0',func=pin_types.OUTPUT),
            Pin(num='6',name='SCL',func=pin_types.INPUT),
            Pin(num='7',name='SDA',func=pin_types.BIDIR),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='9',name='DIG1',func=pin_types.OUTPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'CH455K', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH455K'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-18_W7.62mm'], 'footprint':'Package_DIP:DIP-18_W7.62mm', 'keywords':'WCH Nixie I2C', 'description':'', 'datasheet':'https://www.wch-ic.com/products/CH455.html', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nCH455K\n\nWCH Nixie I2C', 'pins':[
            Pin(num='1',name='DIG0',func=pin_types.OUTPUT),
            Pin(num='10',name='SEG1',func=pin_types.TRISTATE),
            Pin(num='11',name='VCC',func=pin_types.PWRIN),
            Pin(num='12',name='SEG2',func=pin_types.TRISTATE),
            Pin(num='13',name='SEG3',func=pin_types.TRISTATE),
            Pin(num='14',name='SEG4',func=pin_types.TRISTATE),
            Pin(num='15',name='SEG5',func=pin_types.TRISTATE),
            Pin(num='16',name='SEG6',func=pin_types.TRISTATE),
            Pin(num='17',name='SEG7',func=pin_types.TRISTATE),
            Pin(num='2',name='SCL',func=pin_types.INPUT),
            Pin(num='3',name='SDA',func=pin_types.BIDIR),
            Pin(num='4',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='DIG1',func=pin_types.OUTPUT),
            Pin(num='6',name='DIG2',func=pin_types.OUTPUT),
            Pin(num='7',name='DIG3',func=pin_types.OUTPUT),
            Pin(num='9',name='SEG0',func=pin_types.TRISTATE),
            Pin(num='18',name='~{INT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='ISET',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CL220K4-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CL220K4-G'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TO-252-2'], 'footprint':'Package_TO_SOT_SMD:TO-252-2', 'keywords':'Constant Current LED Driver IC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005413A.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nCL220K4-G\n\nConstant Current LED Driver IC', 'pins':[
            Pin(num='1',name='VA',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='VB',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CL220N5-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CL220N5-G'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-3_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-3_Vertical', 'keywords':'Constant Current LED Driver IC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005413A.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nCL220N5-G\n\nConstant Current LED Driver IC', 'pins':[
            Pin(num='1',name='VA',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='VB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIO5661CD6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIO5661CD6'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-6-1EP_2x2mm_P0.65mm_EP1x1.6mm'], 'footprint':'Package_DFN_QFN:DFN-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'keywords':'LED driver single', 'description':'', 'datasheet':'http://www.dioo.com/uploads/product/20190311/e6c7f30c0fbe92fbfa6965c8ef1c5b19.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nDIO5661CD6\n\nLED driver single', 'pins':[
            Pin(num='1',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='LX',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIO5661ST6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIO5661ST6'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'LED driver single', 'description':'', 'datasheet':'http://www.dioo.com/uploads/product/20190311/e6c7f30c0fbe92fbfa6965c8ef1c5b19.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nDIO5661ST6\n\nLED driver single', 'pins':[
            Pin(num='1',name='LX',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VIN',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIO5661TST6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIO5661TST6'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-6'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-6', 'keywords':'LED driver single', 'description':'', 'datasheet':'http://www.dioo.com/uploads/product/20190311/e6c7f30c0fbe92fbfa6965c8ef1c5b19.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nDIO5661TST6\n\nLED driver single', 'pins':[
            Pin(num='1',name='LX',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VIN',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HT1632C-52LQFP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HT1632C-52LQFP'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-52_14x14mm_P1mm'], 'footprint':'Package_QFP:LQFP-52_14x14mm_P1mm', 'keywords':'LED Matrix Driver', 'description':'', 'datasheet':'http://www.holtek.com/documents/10179/116711/HT1632Cv170.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nHT1632C-52LQFP\n\nLED Matrix Driver', 'pins':[
            Pin(num='1',name='ROW11',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='ROW3',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='ROW2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='ROW1',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='ROW0',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='OSC',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='~{WR}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RD}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='ROW10',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='SYNC',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='COM0',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='COM1',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='COM2',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='COM3',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='COM4',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='COM5',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='COM6',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='ROW9',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='COM7',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='ROW31/COM8',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='ROW30/COM9',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='ROW29/COM10',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='ROW28/COM11',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='ROW27/COM12',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='ROW26/COM13',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='ROW25/COM14',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='ROW8',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='ROW24/COM15',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='ROW23',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='ROW22',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='ROW21',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='ROW20',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='ROW19',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='ROW18',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='ROW17',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='ROW16',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='ROW15',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='ROW7',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='ROW14',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='ROW13',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='ROW12',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='ROW6',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='ROW5',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='ROW4',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HV9921N8-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HV9921N8-G'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-89-3'], 'footprint':'Package_TO_SOT_SMD:SOT-89-3', 'keywords':'CC LED Driver High Voltage', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005311A.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nHV9921N8-G\n\nCC LED Driver High Voltage', 'pins':[
            Pin(num='1',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HV9925SG-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HV9925SG-G'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Programmable Current LED Lamp Driver High Voltage', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/hv9925.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nHV9925SG-G\n\nProgrammable Current LED Lamp Driver High Voltage', 'pins':[
            Pin(num='1',name='Rs',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PWMD',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HV9930LG-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HV9930LG-G'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Buck-Boost LED Lamp Driver High Voltage', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/hv9930.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nHV9930LG-G\n\nBuck-Boost LED Lamp Driver High Voltage', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CS1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GATE',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='PWMD',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='CS2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='REF',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HV9931LG-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HV9931LG-G'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Buck-Boost LED Lamp Driver High Voltage PFC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/hv9931.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nHV9931LG-G\n\nBuck-Boost LED Lamp Driver High Voltage PFC', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CS1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GATE',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='PWMD',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='CS2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='REF',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HV9961LG-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HV9961LG-G'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Buck LED Lamp Driver High Voltage Average CC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005588A.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nHV9961LG-G\n\nBuck LED Lamp Driver High Voltage Average CC', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CS',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GATE',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='PWMD',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='LD',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='RT',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HV9961NG-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HV9961NG-G'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'Buck LED Lamp Driver High Voltage Average CC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005588A.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nHV9961NG-G\n\nBuck LED Lamp Driver High Voltage Average CC', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='LD',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='RT',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='CS',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GATE',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='PWMD',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HV9967BK7-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HV9967BK7-G'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_3x3mm_P0.65mm_EP1.55x2.4mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_3x3mm_P0.65mm_EP1.55x2.4mm', 'keywords':'Buck LED Lamp Driver Low Voltage Average CC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/hv9967b.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nHV9967BK7-G\n\nBuck LED Lamp Driver Low Voltage Average CC', 'pins':[
            Pin(num='1',name='SW',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Rs',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PWMD',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='RT',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HV9967BMG-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HV9967BMG-G'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'Buck LED Lamp Driver Low Voltage Average CC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/hv9967b.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nHV9967BMG-G\n\nBuck LED Lamp Driver Low Voltage Average CC', 'pins':[
            Pin(num='1',name='SW',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Rs',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PWMD',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='RT',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HV9972LG-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HV9972LG-G'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Isolated LED Lamp Driver High Voltage CC', 'description':'', 'datasheet':'https://www.mouser.com/ds/2/268/HV9972-272498-1181261.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nHV9972LG-G\n\nIsolated LED Lamp Driver High Voltage CC', 'pins':[
            Pin(num='1',name='BIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VIN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VD',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PWMD',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='CS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GATE',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS31FL3216', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS31FL3216'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.4mm_EP2.4x2.4mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.4mm_EP2.4x2.4mm', 'keywords':'led pwm audio', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/IS31FL3216.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nIS31FL3216\n\nled pwm audio', 'pins':[
            Pin(num='1',name='CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='OUT7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='OUT8',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='GPIO9/OUT9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GPIO10/OUT10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GPIO11/OUT11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GPIO12/OUT12',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GPIO13/OUT13',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GPIO14/OUT14',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GPIO15/OUT15',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GPIO16/OUT16',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='~{INTB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='~{SDB}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='AD',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='C_FILT',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='R_EXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='OUT2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='OUT3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='OUT4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='OUT5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='OUT6',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS31FL3218-GR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS31FL3218-GR'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-24_7.5x15.4mm_P1.27mm'], 'footprint':'Package_SO:SOP-24_7.5x15.4mm_P1.27mm', 'keywords':'led matrix pwm', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/31FL3218.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nIS31FL3218-GR\n\nled matrix pwm', 'pins':[
            Pin(num='1',name='OUT18',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='OUT4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='OUT5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='OUT6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='OUT7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='OUT8',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='OUT9',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='OUT10',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='OUT11',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='OUT12',func=pin_types.OPENCOLL,unit=1),
            Pin(num='19',name='OUT13',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='R_EXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='OUT14',func=pin_types.OPENCOLL,unit=1),
            Pin(num='21',name='OUT15',func=pin_types.OPENCOLL,unit=1),
            Pin(num='22',name='OUT16',func=pin_types.OPENCOLL,unit=1),
            Pin(num='23',name='OUT17',func=pin_types.OPENCOLL,unit=1),
            Pin(num='24',name='~{SDB}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='OUT1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='OUT2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='OUT3',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS31FL3218-QF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS31FL3218-QF'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.7x2.7mm', 'keywords':'led matrix pwm', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/31FL3218.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nIS31FL3218-QF\n\nled matrix pwm', 'pins':[
            Pin(num='1',name='OUT18',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='OUT4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='OUT5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='OUT6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='OUT7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='OUT8',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='OUT9',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='OUT10',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='OUT11',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='OUT12',func=pin_types.OPENCOLL,unit=1),
            Pin(num='19',name='OUT13',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='R_EXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='OUT14',func=pin_types.OPENCOLL,unit=1),
            Pin(num='21',name='OUT15',func=pin_types.OPENCOLL,unit=1),
            Pin(num='22',name='OUT16',func=pin_types.OPENCOLL,unit=1),
            Pin(num='23',name='OUT17',func=pin_types.OPENCOLL,unit=1),
            Pin(num='24',name='~{SDB}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='OUT1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='OUT2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='OUT3',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS31FL3236-TQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS31FL3236-TQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP4.11x4.11mm'], 'footprint':'Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP4.11x4.11mm', 'keywords':'led matrix pwm', 'description':'', 'datasheet':'https://www.lumissil.com/assets/pdf/core/IS31FL3236_DS.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nIS31FL3236-TQ\n\nled matrix pwm', 'pins':[
            Pin(num='1',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='OUT11',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='OUT12',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='OUT13',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='OUT14',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='OUT15',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='OUT16',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OUT17',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='OUT18',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='OUT19',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='OUT20',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='OUT21',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='OUT22',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='OUT23',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OUT24',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='OUT25',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='OUT26',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='OUT27',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='OUT28',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='OUT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='OUT29',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OUT30',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='OUT31',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='OUT32',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='OUT33',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='OUT34',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='OUT35',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='OUT36',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='~{SDB}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='AD',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='R_EXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='SDA',func=pin_types.OPENCOLL,unit=1),
            Pin(num='46',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='OUT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OUT8',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='OUT9',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='OUT10',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS31FL3731-QF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS31FL3731-QF'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.4mm_EP2.3x2.3mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.4mm_EP2.3x2.3mm', 'keywords':'led matrix pwm', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/31FL3731.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nIS31FL3731-QF\n\nled matrix pwm', 'pins':[
            Pin(num='1',name='CA9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='CB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='CB8',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='CB9',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='C_FILT',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='AD',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='CA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='CA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='CA4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='CA5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='CA6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='CA7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='CA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~{SDB}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{INTB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='R_EXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS31FL3731-SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS31FL3731-SA'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'led matrix pwm', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/31FL3731.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nIS31FL3731-SA\n\nled matrix pwm', 'pins':[
            Pin(num='1',name='CA9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='CB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='CB8',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='CB9',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='C_FILT',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='AD',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='CA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='CA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='CA4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='CA5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='CA6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='CA7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='CA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{SDB}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{INTB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='R_EXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS31FL3733-QF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS31FL3733-QF'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm', 'keywords':'led matrix pwm', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/IS31FL3733.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nIS31FL3733-QF\n\nled matrix pwm', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='SW8',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SW9',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='SW10',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SW11',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SW12',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='CS2',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='CS3',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='CS4',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='SW1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='CS5',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='CS6',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='CS7',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='CS8',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='CS9',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='CS10',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='CS11',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='CS12',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='PVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SW2',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='CS13',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='CS14',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='CS15',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='CS16',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='RSET',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VIO',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SW3',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='ADDR1',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='ADDR2',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='~{INTB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='46',name='~{SDB}',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='IICRST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SW4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SW5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SW6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SW7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS31FL3733-TQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS31FL3733-TQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP5x5mm'], 'footprint':'Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP5x5mm', 'keywords':'led matrix pwm', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/IS31FL3733.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nIS31FL3733-TQ\n\nled matrix pwm', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='SW8',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SW9',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='SW10',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SW11',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SW12',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='CS2',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='CS3',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='CS4',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='SW1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='CS5',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='CS6',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='CS7',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='CS8',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='CS9',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='CS10',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='CS11',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='CS12',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='PVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SW2',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='CS13',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='CS14',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='CS15',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='CS16',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='RSET',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VIO',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SW3',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='ADDR1',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='ADDR2',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='~{INTB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='46',name='~{SDB}',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='IICRST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SW4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SW5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SW6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SW7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS31FL3736', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS31FL3736'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-40-1EP_5x5mm_P0.4mm_EP3.8x3.8mm'], 'footprint':'Package_DFN_QFN:QFN-40-1EP_5x5mm_P0.4mm_EP3.8x3.8mm', 'keywords':'led matrix pwm', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/31FL3736.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nIS31FL3736\n\nled matrix pwm', 'pins':[
            Pin(num='1',name='SW1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SW9',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='SW10',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SW11',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SW12',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='CS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='CS2',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='PVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='CS3',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='CS4',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='SW2',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='CS5',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='CS6',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='PVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='CS7',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='CS8',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='SW3',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='RSET',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VIO',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='ADDR1',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='ADDR2',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{INTB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='38',name='~{SDB}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='IICRST',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='SW4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SW5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SW6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SW7',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SW8',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS31FL3737', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS31FL3737'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-40-1EP_5x5mm_P0.4mm_EP3.8x3.8mm'], 'footprint':'Package_DFN_QFN:QFN-40-1EP_5x5mm_P0.4mm_EP3.8x3.8mm', 'keywords':'led matrix pwm', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/31FL3737.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nIS31FL3737\n\nled matrix pwm', 'pins':[
            Pin(num='1',name='SW1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SW9',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='SW10',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SW11',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SW12',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='CS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='CS2',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='CS3',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='CS4',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='PVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SW2',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='CS5',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='CS6',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='CS7',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='CS8',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='CS9',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='CS10',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='PVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='CS11',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='CS12',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SW3',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='RSET',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VIO',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{INTB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='38',name='~{SDB}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='IICRST',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='SW4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SW5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SW6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SW7',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SW8',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS31LT3360', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS31LT3360'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-89-5'], 'footprint':'Package_TO_SOT_SMD:SOT-89-5', 'keywords':'Switching LED driver', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/31LT3360.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nIS31LT3360\n\nSwitching LED driver', 'pins':[
            Pin(num='1',name='LX',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ADJ',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='ISENSE',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VIN',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KTD2026', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KTD2026'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_1.5x1.5mm_P0.4mm_EP0.7x1.2mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_1.5x1.5mm_P0.4mm_EP0.7x1.2mm', 'keywords':'kinetic cc sink RGB', 'description':'', 'datasheet':'https://www.kinet-ic.com/uploads/KTD2026-7-04h.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nKTD2026\n\nkinetic cc sink RGB', 'pins':[
            Pin(num='1',name='ST',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='D3',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='D2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KTD2027', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KTD2027'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_1.5x1.5mm_P0.4mm_EP0.7x1.2mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_1.5x1.5mm_P0.4mm_EP0.7x1.2mm', 'keywords':'kinetic cc sink RGB', 'description':'', 'datasheet':'https://www.kinet-ic.com/uploads/KTD2026-7-04h.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nKTD2027\n\nkinetic cc sink RGB', 'pins':[
            Pin(num='1',name='D4',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='D3',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='D2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED1642GWPTR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED1642GWPTR'}), 'ref_prefix':'U', 'fplist':['Package_SO:QSOP-24_3.9x8.7mm_P0.635mm'], 'footprint':'Package_SO:QSOP-24_3.9x8.7mm_P0.635mm', 'keywords':'PWM LED driver error detection brightness QSOP-24', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/led1642gw.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLED1642GWPTR\n\nPWM LED driver error detection brightness QSOP-24', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='OUT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='OUT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='OUT8',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='OUT9',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='OUT10',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OUT11',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='OUT12',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='OUT13',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='OUT14',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT15',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='PWCLK',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='R-EXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='OUT4',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED1642GWQTR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED1642GWQTR'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.15x2.15mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.15x2.15mm', 'keywords':'PWM LED driver error detection brightness QFN-24', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/led1642gw.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLED1642GWQTR\n\nPWM LED driver error detection brightness QFN-24', 'pins':[
            Pin(num='1',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OUT8',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='OUT9',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='OUT10',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='OUT11',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='OUT12',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='OUT13',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OUT14',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='OUT15',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='PWCLK',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='R-EXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='EP',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OUT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='OUT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='OUT7',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED1642GWTTR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED1642GWTTR'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'PWM LED driver error detection brightness TSSOP-24', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/led1642gw.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLED1642GWTTR\n\nPWM LED driver error detection brightness TSSOP-24', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='OUT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='OUT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='OUT8',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='OUT9',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='OUT10',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OUT11',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='OUT12',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='OUT13',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='OUT14',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT15',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='PWCLK',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='R-EXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='OUT4',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED1642GWXTTR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED1642GWXTTR'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24-1EP_4.4x7.8mm_P0.65mm_EP3.2x5mm'], 'footprint':'Package_SO:TSSOP-24-1EP_4.4x7.8mm_P0.65mm_EP3.2x5mm', 'keywords':'PWM LED driver error detection brightness TSSOP-24', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/led1642gw.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLED1642GWXTTR\n\nPWM LED driver error detection brightness TSSOP-24', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='OUT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='OUT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='OUT8',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='OUT9',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='OUT10',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OUT11',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='OUT12',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='OUT13',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='OUT14',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT15',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='PWCLK',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='R-EXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='EP',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='OUT4',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED5000', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED5000'}), 'ref_prefix':'U', 'fplist':['Package_SO:HSOP-8-1EP_3.9x4.9mm_P1.27mm_EP2.41x3.1mm'], 'footprint':'Package_SO:HSOP-8-1EP_3.9x4.9mm_P1.27mm_EP2.41x3.1mm', 'keywords':'LED buck driver', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/led5000.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLED5000\n\nLED buck driver', 'pins':[
            Pin(num='1',name='BOOT',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='DIM',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='INH',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='COMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='SW',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM3914N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM3914N'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-18_W7.62mm'], 'footprint':'Package_DIP:DIP-18_W7.62mm', 'keywords':'LED driver bar dot', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/lm3914.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLM3914N\n\nLED driver bar dot', 'pins':[
            Pin(num='1',name='LED1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='LED10',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='LED9',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='LED8',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='LED7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='LED6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='LED5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='LED4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='LED3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='LED2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='RLO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SIG',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RHI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='REFOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='REFADJ',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='MODE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM3914V', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM3914V'}), 'ref_prefix':'U', 'fplist':['Package_LCC:PLCC-20'], 'footprint':'Package_LCC:PLCC-20', 'keywords':'LED driver bar dot', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/lm3914.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLM3914V\n\nLED driver bar dot', 'pins':[
            Pin(num='1',name='LED1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='REFADJ',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='LED10',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='LED9',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='LED8',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='LED7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='LED6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='LED5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='LED4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='19',name='LED3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='LED2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='RLO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SIG',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RHI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='REFOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LP5036', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LP5036'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-46-1EP_5x6mm_P0.4mm_EP2.8x3.8mm'], 'footprint':'Package_DFN_QFN:VQFN-46-1EP_5x6mm_P0.4mm_EP2.8x3.8mm', 'keywords':'PWM LED driver I2C', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lp5036.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLP5036\n\nPWM LED driver I2C', 'pins':[
            Pin(num='1',name='OUT0',func=pin_types.PWROUT,unit=1),
            Pin(num='10',name='OUT9',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='OUT10',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='OUT11',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='OUT12',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='OUT13',func=pin_types.PWROUT,unit=1),
            Pin(num='15',name='OUT14',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='OUT15',func=pin_types.PWROUT,unit=1),
            Pin(num='17',name='OUT16',func=pin_types.PWROUT,unit=1),
            Pin(num='18',name='OUT17',func=pin_types.PWROUT,unit=1),
            Pin(num='19',name='OUT18',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='OUT1',func=pin_types.PWROUT,unit=1),
            Pin(num='20',name='OUT19',func=pin_types.PWROUT,unit=1),
            Pin(num='21',name='OUT20',func=pin_types.PWROUT,unit=1),
            Pin(num='22',name='OUT21',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='OUT22',func=pin_types.PWROUT,unit=1),
            Pin(num='24',name='OUT23',func=pin_types.PWROUT,unit=1),
            Pin(num='25',name='OUT24',func=pin_types.PWROUT,unit=1),
            Pin(num='26',name='OUT25',func=pin_types.PWROUT,unit=1),
            Pin(num='27',name='OUT26',func=pin_types.PWROUT,unit=1),
            Pin(num='28',name='OUT27',func=pin_types.PWROUT,unit=1),
            Pin(num='29',name='OUT28',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='OUT2',func=pin_types.PWROUT,unit=1),
            Pin(num='30',name='OUT29',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='OUT30',func=pin_types.PWROUT,unit=1),
            Pin(num='32',name='OUT31',func=pin_types.PWROUT,unit=1),
            Pin(num='33',name='OUT32',func=pin_types.PWROUT,unit=1),
            Pin(num='34',name='OUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='35',name='OUT34',func=pin_types.PWROUT,unit=1),
            Pin(num='36',name='OUT35',func=pin_types.PWROUT,unit=1),
            Pin(num='37',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='ADDR0',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='ADDR1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='OUT3',func=pin_types.PWROUT,unit=1),
            Pin(num='40',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='IREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT4',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='OUT5',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='OUT6',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='OUT7',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='OUT8',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT3465', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT3465'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-6'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-6', 'keywords':'Switching LED driver', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/3465fa.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLT3465\n\nSwitching LED driver', 'pins':[
            Pin(num='1',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SW',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT3755xMSE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT3755xMSE'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-16-1EP_3x4mm_P0.5mm_EP1.65x2.85mm'], 'footprint':'Package_SO:MSOP-16-1EP_3x4mm_P0.5mm_EP1.65x2.85mm', 'keywords':'Boost Buck Buck-Boost SEPIC Flyback', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/37551fd.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLT3755xMSE\n\nBoost Buck Buck-Boost SEPIC Flyback', 'pins':[
            Pin(num='1',name='PWMOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='SS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='RT',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{SHDN}/UVLO',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='INTVCC',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GATE',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='ISN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='ISP',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VC',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VREF',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{OPENLED}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT3755xMSE-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT3755xMSE-1'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-16-1EP_3x4mm_P0.5mm_EP1.65x2.85mm'], 'footprint':'Package_SO:MSOP-16-1EP_3x4mm_P0.5mm_EP1.65x2.85mm', 'keywords':'Boost Buck Buck-Boost SEPIC Flyback', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/37551fd.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLT3755xMSE-1\n\nBoost Buck Buck-Boost SEPIC Flyback', 'pins':[
            Pin(num='1',name='PWMOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='SS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='RT',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{SHDN}/UVLO',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='INTVCC',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GATE',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='ISN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='ISP',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VC',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VREF',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SYNC',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT3755xUD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT3755xUD'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.45x1.45mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.45x1.45mm', 'keywords':'Boost Buck Buck-Boost SEPIC Flyback', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/37551fd.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLT3755xUD\n\nBoost Buck Buck-Boost SEPIC Flyback', 'pins':[
            Pin(num='1',name='VREF',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GATE',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='PWMOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='ISN',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='ISP',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VC',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{OPENLED}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SS',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{SHDN}/UVLO',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='INTVCC',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='SENSE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT3755xUD-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT3755xUD-1'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.45x1.45mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.45x1.45mm', 'keywords':'Boost Buck Buck-Boost SEPIC Flyback', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/37551fd.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLT3755xUD-1\n\nBoost Buck Buck-Boost SEPIC Flyback', 'pins':[
            Pin(num='1',name='VREF',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GATE',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='PWMOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='ISN',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='ISP',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VC',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SS',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SHDN/UVLO',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='INTVCC',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='SENSE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT8391xFE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT8391xFE'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.74x4.75mm_ThermalVias'], 'footprint':'Package_SO:TSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.74x4.75mm_ThermalVias', 'keywords':'60V Synchronous 4-Switch Buck-Boost LED Controller', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/lt8391.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLT8391xFE\n\n60V Synchronous 4-Switch Buck-Boost LED Controller', 'pins':[
            Pin(num='1',name='BG1',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='RP',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VREF',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='CTRL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='ISP',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='ISN',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CTRL2',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='SS',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='BST1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='VC',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='RT',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='SYNC/SPRD',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PWMTG',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='VOUT',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='TG2',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='SW2',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='BST2',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='BG2',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SW1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='TG1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='LSP',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='LSN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='INTVCC',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='EN/UVLO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX7219', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX7219'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'LED 8-Digit Display Driver', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX7219-MAX7221.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nMAX7219\n\nLED 8-Digit Display Driver', 'pins':[
            Pin(num='1',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DIG_5',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='DIG_1',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='LOAD',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SEG_A',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SEG_F',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='SEG_B',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SEG_G',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='ISET',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='DIG_0',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='SEG_C',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='SEG_E',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='SEG_DP',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='SEG_D',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='DIG_4',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DIG_6',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='DIG_2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='DIG_3',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='DIG_7',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX7221xNG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX7221xNG'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-24_W7.62mm'], 'footprint':'Package_DIP:DIP-24_W7.62mm', 'keywords':'spi qspi microwire', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX7219-MAX7221.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nMAX7221xNG\n\nspi qspi microwire', 'pins':[
            Pin(num='1',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DIG_5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='DIG_1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SEG_A',func=pin_types.OPENEMIT,unit=1),
            Pin(num='15',name='SEG_F',func=pin_types.OPENEMIT,unit=1),
            Pin(num='16',name='SEG_B',func=pin_types.OPENEMIT,unit=1),
            Pin(num='17',name='SEG_G',func=pin_types.OPENEMIT,unit=1),
            Pin(num='18',name='ISET',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='DIG_0',func=pin_types.OPENCOLL,unit=1),
            Pin(num='20',name='SEG_C',func=pin_types.OPENEMIT,unit=1),
            Pin(num='21',name='SEG_E',func=pin_types.OPENEMIT,unit=1),
            Pin(num='22',name='SEG_DP',func=pin_types.OPENEMIT,unit=1),
            Pin(num='23',name='SEG_D',func=pin_types.OPENEMIT,unit=1),
            Pin(num='24',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='DIG_4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DIG_6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='DIG_2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='DIG_3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='DIG_7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX7221xWG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX7221xWG'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-24W_7.5x15.4mm_P1.27mm'], 'footprint':'Package_SO:SOIC-24W_7.5x15.4mm_P1.27mm', 'keywords':'spi qspi microwire', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX7219-MAX7221.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nMAX7221xWG\n\nspi qspi microwire', 'pins':[
            Pin(num='1',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DIG_5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='DIG_1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SEG_A',func=pin_types.OPENEMIT,unit=1),
            Pin(num='15',name='SEG_F',func=pin_types.OPENEMIT,unit=1),
            Pin(num='16',name='SEG_B',func=pin_types.OPENEMIT,unit=1),
            Pin(num='17',name='SEG_G',func=pin_types.OPENEMIT,unit=1),
            Pin(num='18',name='ISET',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='DIG_0',func=pin_types.OPENCOLL,unit=1),
            Pin(num='20',name='SEG_C',func=pin_types.OPENEMIT,unit=1),
            Pin(num='21',name='SEG_E',func=pin_types.OPENEMIT,unit=1),
            Pin(num='22',name='SEG_DP',func=pin_types.OPENEMIT,unit=1),
            Pin(num='23',name='SEG_D',func=pin_types.OPENEMIT,unit=1),
            Pin(num='24',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='DIG_4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DIG_6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='DIG_2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='DIG_3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='DIG_7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MBI5252GFN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MBI5252GFN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:HVQFN-24-1EP_4x4mm_P0.5mm_EP2.5x2.5mm'], 'footprint':'Package_DFN_QFN:HVQFN-24-1EP_4x4mm_P0.5mm_EP2.5x2.5mm', 'keywords':'Shift Register LED driver 16 bit', 'description':'', 'datasheet':'https://datasheet.lcsc.com/lcsc/1809031521_MBI-MBI5252GP-A_C261127.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nMBI5252GFN\n\nShift Register LED driver 16 bit', 'pins':[
            Pin(num='1',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{OUT8}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='~{OUT9}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='~{OUT10}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='~{OUT11}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='~{OUT12}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='~{OUT13}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='~{OUT14}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='~{OUT15}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='19',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{OUT0}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='20',name='GCLK',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='R-EXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='DCLK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PAD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{OUT1}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~{OUT2}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='~{OUT3}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='~{OUT4}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='~{OUT5}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='~{OUT6}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='~{OUT7}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MBI5252GP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MBI5252GP'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-24_3.9x8.7mm_P0.635mm'], 'footprint':'Package_SO:SSOP-24_3.9x8.7mm_P0.635mm', 'keywords':'Shift Register LED driver 16 bit', 'description':'', 'datasheet':'https://datasheet.lcsc.com/lcsc/1809031521_MBI-MBI5252GP-A_C261127.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nMBI5252GP\n\nShift Register LED driver 16 bit', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{OUT5}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='~{OUT6}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='~{OUT7}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='~{OUT8}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='~{OUT9}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='~{OUT10}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='~{OUT11}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='~{OUT12}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='~{OUT13}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='19',name='~{OUT14}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='~{OUT15}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='21',name='GCLK',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='R-EXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='DCLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{OUT0}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='~{OUT1}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='~{OUT2}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='~{OUT3}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='~{OUT4}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC14495P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC14495P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-16_W7.62mm'], 'footprint':'Package_DIP:DIP-16_W7.62mm', 'keywords':'driver 7-segment', 'description':'', 'datasheet':'https://www.futurlec.com/Datasheet/Motorola/MC14495.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nMC14495P\n\ndriver 7-segment', 'pins':[
            Pin(num='1',name='e',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{VCR}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='a',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='b',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='c',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='d',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='f',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='g',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='h+i',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{CLK}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='C',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1643xMS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1643xMS'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'LED driver low voltage', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/20005208A.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nMCP1643xMS\n\nLED driver low voltage', 'pins':[
            Pin(num='1',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='VFB',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='SW',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='SGND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VIN',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP1662-xOT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP1662-xOT'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'step-up led driver uvlo', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/20005316E.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nMCP1662-xOT\n\nstep-up led driver uvlo', 'pins':[
            Pin(num='1',name='SW',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='V_{FB}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='V_{IN}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MP3362GJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MP3362GJ'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-8'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-8', 'keywords':'LED driver', 'description':'', 'datasheet':'https://www.monolithicpower.com/en/documentview/productdocument/index/version/2/document_type/Datasheet/lang/en/sku/MP3362GJ/document_id/9117/', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nMP3362GJ\n\nLED driver', 'pins':[
            Pin(num='1',name='SW',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='COMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='OSC',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='FB',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='OVP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MPQ2483DQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MPQ2483DQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-10-1EP_3x3mm_P0.5mm_EP1.7x2.5mm'], 'footprint':'Package_DFN_QFN:DFN-10-1EP_3x3mm_P0.5mm_EP1.7x2.5mm', 'keywords':'LED driver', 'description':'', 'datasheet':'https://www.monolithicpower.com/pub/media/document/MPQ2483_r1.05.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nMPQ2483DQ\n\nLED driver', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SW',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OVP',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='COMP',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RSET',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='EN/DIM',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='INGND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='BST',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NCP5623DTBR2G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCP5623DTBR2G'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'LED RGB', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/NCP5623-D.PDF', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nNCP5623DTBR2G\n\nLED RGB', 'pins':[
            Pin(num='1',name='IC',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='I_{REF}',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='V_{DET}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='V_{BAT}',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='IC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='LED3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='LED2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='LED1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NCR401U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCR401U'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SC-74-6_1.55x2.9mm_P0.95mm'], 'footprint':'Package_TO_SOT_SMD:SC-74-6_1.55x2.9mm_P0.95mm', 'keywords':'LED driver constant current', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/NCR401U.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nNCR401U\n\nLED driver constant current', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='IOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='IOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='REXT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9531PW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9531PW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'led pwm rgb smbus', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9531.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nPCA9531PW\n\nled pwm rgb smbus', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='LED5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='LED6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='LED7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='LED0',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='LED1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='LED2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='LED3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='LED4',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9635', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9635'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'led pwm rgb rgba', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9635.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nPCA9635\n\nled pwm rgb rgba', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='LED4',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='LED5',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='LED6',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='LED7',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='LED8',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='LED9',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='LED10',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='LED11',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='LED12',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='LED13',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='LED14',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='LED15',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='LED0',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='LED1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='LED2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='LED3',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9685BS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9685BS'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_6x6mm_P0.65mm_EP4.25x4.25mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_6x6mm_P0.65mm_EP4.25x4.25mm', 'keywords':'PWM LED driver I2C QFN', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/PCA9685.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nPCA9685BS\n\nPWM LED driver I2C QFN', 'pins':[
            Pin(num='1',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='LED7',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='LED8',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='LED9',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='LED10',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='LED11',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='LED12',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='LED13',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='LED14',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='LED15',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='EXTCLK',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='LED0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='LED1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='LED2',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='LED3',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='LED4',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='LED5',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='LED6',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9685PW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9685PW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'PWM LED driver I2C TSSOP', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/PCA9685.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nPCA9685PW\n\nPWM LED driver I2C TSSOP', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='LED4',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='LED5',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='LED6',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='LED7',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='LED8',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='LED9',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='LED10',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='LED11',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='LED12',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='LED13',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='LED14',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='LED15',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='EXTCLK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='LED0',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='LED1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='LED2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='LED3',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9745BTW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9745BTW'}), 'ref_prefix':'U', 'fplist':['Package_SO:NXP_HTSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.2x3.4mm'], 'footprint':'Package_SO:NXP_HTSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.2x3.4mm', 'keywords':'pwm led current spi', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9745B.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nPCA9745BTW\n\npwm led current spi', 'pins':[
            Pin(num='1',name='REXT',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='LED4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='LED5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='LED6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='LED7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='LED8',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='LED9',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='LED10',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='LED11',func=pin_types.OPENCOLL,unit=1),
            Pin(num='19',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='LED12',func=pin_types.OPENCOLL,unit=1),
            Pin(num='21',name='LED13',func=pin_types.OPENCOLL,unit=1),
            Pin(num='22',name='LED14',func=pin_types.OPENCOLL,unit=1),
            Pin(num='23',name='LED15',func=pin_types.OPENCOLL,unit=1),
            Pin(num='24',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='LED0',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='LED1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='LED2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='LED3',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RCD-24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RCD-24'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_RECOM_RCD-24_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_RECOM_RCD-24_THT', 'keywords':'Led Driver DC-DC', 'description':'', 'datasheet':'https://g.recomcdn.com/media/Datasheet/pdf/.fYUQjOlW/.t2a80a771bdbb0ef300f7/Datasheet-93/RCD-24.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nRCD-24\n\nLed Driver DC-DC', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Analogue_Dimming',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PWM/ON/OFF',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ST1CC40DR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ST1CC40DR'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'DC/DC Buck Conwerter 3A Low Voltage Input LED Lighting', 'description':'', 'datasheet':'http://www.st.com/content/ccc/resource/technical/document/datasheet/group3/71/e8/26/3c/c8/cc/46/e6/CD00292360/files/CD00292360.pdf/jcr:content/translations/en.CD00292360.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nST1CC40DR\n\nDC/DC Buck Conwerter 3A Low Voltage Input LED Lighting', 'pins':[
            Pin(num='1',name='SW',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='PGND',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='VINA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='INH',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VINSW',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ST1CC40PUR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ST1CC40PUR'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_4x4mm_P0.8mm_EP2.5x3.6mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_4x4mm_P0.8mm_EP2.5x3.6mm', 'keywords':'DC/DC Buck Conwerter 3A Low Voltage Input LED Lighting', 'description':'', 'datasheet':'http://www.st.com/content/ccc/resource/technical/document/datasheet/group3/71/e8/26/3c/c8/cc/46/e6/CD00292360/files/CD00292360.pdf/jcr:content/translations/en.CD00292360.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nST1CC40PUR\n\nDC/DC Buck Conwerter 3A Low Voltage Input LED Lighting', 'pins':[
            Pin(num='1',name='VINA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='INH',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VINSW',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='SW',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='PGND',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='PAD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STP08CP05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STP08CP05'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Shift Register LED driver 8 bit', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stp08cp05.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nSTP08CP05\n\nShift Register LED driver 8 bit', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='OUT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='OUT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='R-EXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='OUT4',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STP08CP05XT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STP08CP05XT'}), 'ref_prefix':'U', 'fplist':['Package_SO:HTSSOP-16-1EP_4.4x5mm_P0.65mm_EP3x3mm'], 'footprint':'Package_SO:HTSSOP-16-1EP_4.4x5mm_P0.65mm_EP3x3mm', 'keywords':'Shift Register LED driver 8 bit', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stp08cp05.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nSTP08CP05XT\n\nShift Register LED driver 8 bit', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='OUT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='OUT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='R-EXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='OUT4',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STP16CP05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STP16CP05'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Shift Register LED driver 16 bit', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stp16cp05.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nSTP16CP05\n\nShift Register LED driver 16 bit', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{OUT5}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{OUT6}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{OUT7}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{OUT8}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{OUT9}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{OUT10}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='~{OUT11}',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='~{OUT12}',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='~{OUT13}',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='~{OUT14}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='~{OUT15}',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='~{OE/DM2}',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='R-EXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='LE/DM1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{OUT0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{OUT1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{OUT2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{OUT3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{OUT4}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STP16CP05XT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STP16CP05XT'}), 'ref_prefix':'U', 'fplist':['Package_SO:HTSSOP-24-1EP_4.4x7.8mm_P0.65mm_EP3.2x5mm'], 'footprint':'Package_SO:HTSSOP-24-1EP_4.4x7.8mm_P0.65mm_EP3.2x5mm', 'keywords':'Shift Register LED driver 16 bit', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stp16cp05.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nSTP16CP05XT\n\nShift Register LED driver 16 bit', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{OUT5}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{OUT6}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{OUT7}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{OUT8}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{OUT9}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{OUT10}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='~{OUT11}',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='~{OUT12}',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='~{OUT13}',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='~{OUT14}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='~{OUT15}',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='~{OE/DM2}',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='R-EXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='LE/DM1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{OUT0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{OUT1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{OUT2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{OUT3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{OUT4}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA6507RUE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA6507RUE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_X2QFN-RUE-12_1.4x2mm_P0.4mm'], 'footprint':'Package_DFN_QFN:Texas_X2QFN-RUE-12_1.4x2mm_P0.4mm', 'keywords':'led driver i2c 7-bit', 'description':'', 'datasheet':'https://www.ti.com/lit/gpn/tca6507', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nTCA6507RUE\n\nled driver i2c 7-bit', 'pins':[
            Pin(num='1',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='P5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='P6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='P0',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='P1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='P2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='P3',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLC59108xPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLC59108xPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'LED current driver', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tlc59108.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nTLC59108xPW\n\nLED current driver', 'pins':[
            Pin(num='1',name='REXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~{OUT3}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='~{OUT4}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='~{OUT5}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~{OUT6}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='~{OUT7}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{OUT0}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='~{OUT1}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{OUT2}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLC5916', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLC5916'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'LED Constant-Current Driver', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tlc5916.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nTLC5916\n\nLED Constant-Current Driver', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{OUT5}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='~{OUT6}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='~{OUT7}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='~{OE}(ED2)',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='R-EXT',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='LE(ED1)',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~{OUT0}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='~{OUT1}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='~{OUT2}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='~{OUT3}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='~{OUT4}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLC5940NT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLC5940NT'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'PWM LED driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tlc5940.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nTLC5940NT\n\nPWM LED driver', 'pins':[
            Pin(num='1',name='OUT1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='OUT10',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='OUT11',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='OUT12',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='OUT13',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='OUT14',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='OUT15',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='XERR',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='SOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='GSCLK',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='DCPRG',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='OUT2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='20',name='IREF',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='BLANK',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='XLAT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='SIN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VPRG',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='OUT0',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='OUT3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='OUT4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='OUT5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='OUT6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='OUT7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='OUT8',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='OUT9',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLC5940PWP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLC5940PWP'}), 'ref_prefix':'U', 'fplist':['Package_SO:HTSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP3.4x9.5mm_Mask2.4x6.17mm_ThermalVias'], 'footprint':'Package_SO:HTSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP3.4x9.5mm_Mask2.4x6.17mm_ThermalVias', 'keywords':'PWM LED driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tlc5940.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nTLC5940PWP\n\nPWM LED driver', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUT3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='OUT4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='OUT5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='OUT6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='OUT7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='OUT8',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='OUT9',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='OUT10',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='OUT11',func=pin_types.OPENCOLL,unit=1),
            Pin(num='19',name='OUT12',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='BLANK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT13',func=pin_types.OPENCOLL,unit=1),
            Pin(num='21',name='OUT14',func=pin_types.OPENCOLL,unit=1),
            Pin(num='22',name='OUT15',func=pin_types.OPENCOLL,unit=1),
            Pin(num='23',name='XERR',func=pin_types.OPENCOLL,unit=1),
            Pin(num='24',name='SOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='GSCLK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='DCPRG',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='IREF',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PAD',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='XLAT',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SIN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VPRG',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='OUT0',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='OUT1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='OUT2',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLC5947DAP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLC5947DAP'}), 'ref_prefix':'U', 'fplist':['Package_SO:HTSSOP-32-1EP_6.1x11mm_P0.65mm_EP5.2x11mm_Mask4.11x4.36mm_ThermalVias'], 'footprint':'Package_SO:HTSSOP-32-1EP_6.1x11mm_P0.65mm_EP5.2x11mm_Mask4.11x4.36mm_ThermalVias', 'keywords':'PWM LED driver HTSSOP', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tlc5947.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nTLC5947DAP\n\nPWM LED driver HTSSOP', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN),
            Pin(num='10',name='OUT5',func=pin_types.OUTPUT),
            Pin(num='11',name='OUT6',func=pin_types.OUTPUT),
            Pin(num='12',name='OUT7',func=pin_types.OUTPUT),
            Pin(num='13',name='OUT8',func=pin_types.OUTPUT),
            Pin(num='14',name='OUT9',func=pin_types.OUTPUT),
            Pin(num='15',name='OUT10',func=pin_types.OUTPUT),
            Pin(num='16',name='OUT11',func=pin_types.OUTPUT),
            Pin(num='17',name='OUT12',func=pin_types.OUTPUT),
            Pin(num='18',name='OUT13',func=pin_types.OUTPUT),
            Pin(num='19',name='OUT14',func=pin_types.OUTPUT),
            Pin(num='2',name='BLANK',func=pin_types.INPUT),
            Pin(num='20',name='OUT15',func=pin_types.OUTPUT),
            Pin(num='21',name='OUT16',func=pin_types.OUTPUT),
            Pin(num='22',name='OUT17',func=pin_types.OUTPUT),
            Pin(num='23',name='OUT18',func=pin_types.OUTPUT),
            Pin(num='24',name='OUT19',func=pin_types.OUTPUT),
            Pin(num='25',name='OUT20',func=pin_types.OUTPUT),
            Pin(num='26',name='OUT21',func=pin_types.OUTPUT),
            Pin(num='27',name='OUT22',func=pin_types.OUTPUT),
            Pin(num='28',name='OUT23',func=pin_types.OUTPUT),
            Pin(num='29',name='SOUT',func=pin_types.OUTPUT),
            Pin(num='3',name='SCLK',func=pin_types.INPUT),
            Pin(num='30',name='XLAT',func=pin_types.INPUT),
            Pin(num='31',name='IREF',func=pin_types.INPUT),
            Pin(num='32',name='VCC',func=pin_types.PWRIN),
            Pin(num='33',name='PowerPAD',func=pin_types.PWRIN),
            Pin(num='4',name='SIN',func=pin_types.INPUT),
            Pin(num='5',name='OUT0',func=pin_types.OUTPUT),
            Pin(num='6',name='OUT1',func=pin_types.OUTPUT),
            Pin(num='7',name='OUT2',func=pin_types.OUTPUT),
            Pin(num='8',name='OUT3',func=pin_types.OUTPUT),
            Pin(num='9',name='OUT4',func=pin_types.OUTPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TLC5947RHB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLC5947RHB'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'PWM LED driver QFN', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tlc5947.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nTLC5947RHB\n\nPWM LED driver QFN', 'pins':[
            Pin(num='1',name='OUT0',func=pin_types.OUTPUT),
            Pin(num='10',name='OUT9',func=pin_types.OUTPUT),
            Pin(num='11',name='OUT10',func=pin_types.OUTPUT),
            Pin(num='12',name='OUT11',func=pin_types.OUTPUT),
            Pin(num='13',name='OUT12',func=pin_types.OUTPUT),
            Pin(num='14',name='OUT13',func=pin_types.OUTPUT),
            Pin(num='15',name='OUT14',func=pin_types.OUTPUT),
            Pin(num='16',name='OUT15',func=pin_types.OUTPUT),
            Pin(num='17',name='OUT16',func=pin_types.OUTPUT),
            Pin(num='18',name='OUT17',func=pin_types.OUTPUT),
            Pin(num='19',name='OUT18',func=pin_types.OUTPUT),
            Pin(num='2',name='OUT1',func=pin_types.OUTPUT),
            Pin(num='20',name='OUT19',func=pin_types.OUTPUT),
            Pin(num='21',name='OUT20',func=pin_types.OUTPUT),
            Pin(num='22',name='OUT21',func=pin_types.OUTPUT),
            Pin(num='23',name='OUT22',func=pin_types.OUTPUT),
            Pin(num='24',name='OUT23',func=pin_types.OUTPUT),
            Pin(num='25',name='SOUT',func=pin_types.OUTPUT),
            Pin(num='26',name='XLAT',func=pin_types.INPUT),
            Pin(num='27',name='IREF',func=pin_types.INPUT),
            Pin(num='28',name='VCC',func=pin_types.PWRIN),
            Pin(num='29',name='GND',func=pin_types.PWRIN),
            Pin(num='3',name='OUT2',func=pin_types.OUTPUT),
            Pin(num='30',name='BLANK',func=pin_types.INPUT),
            Pin(num='31',name='SCLK',func=pin_types.INPUT),
            Pin(num='32',name='SIN',func=pin_types.INPUT),
            Pin(num='33',name='PowerPAD',func=pin_types.PWRIN),
            Pin(num='4',name='OUT3',func=pin_types.OUTPUT),
            Pin(num='5',name='OUT4',func=pin_types.OUTPUT),
            Pin(num='6',name='OUT5',func=pin_types.OUTPUT),
            Pin(num='7',name='OUT6',func=pin_types.OUTPUT),
            Pin(num='8',name='OUT7',func=pin_types.OUTPUT),
            Pin(num='9',name='OUT8',func=pin_types.OUTPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TLC5949PWP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLC5949PWP'}), 'ref_prefix':'U', 'fplist':['Package_SO:HTSSOP-24-1EP_4.4x7.8mm_P0.65mm_EP3.4x7.8mm_Mask2.4x2.98mm'], 'footprint':'Package_SO:HTSSOP-24-1EP_4.4x7.8mm_P0.65mm_EP3.4x7.8mm_Mask2.4x2.98mm', 'keywords':'led driver', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tlc5949.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nTLC5949PWP\n\nled driver', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUT5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='OUT6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='OUT7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='OUT8',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='OUT9',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='OUT10',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='OUT11',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='OUT12',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='OUT13',func=pin_types.OPENCOLL,unit=1),
            Pin(num='19',name='OUT14',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='SIN',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT15',func=pin_types.OPENCOLL,unit=1),
            Pin(num='21',name='GSCLK',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='IREF',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='LAT',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='OUT0',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='OUT1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='OUT2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='OUT3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='OUT4',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLC5951DAP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLC5951DAP'}), 'ref_prefix':'U', 'fplist':['Package_SO:HTSSOP-38-1EP_6.1x12.5mm_P0.65mm_EP5.2x12.5mm_Mask3.39x6.35mm_ThermalVias'], 'footprint':'Package_SO:HTSSOP-38-1EP_6.1x12.5mm_P0.65mm_EP5.2x12.5mm_Mask3.39x6.35mm_ThermalVias', 'keywords':'led driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tlc5951.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nTLC5951DAP\n\nled driver', 'pins':[
            Pin(num='1',name='GSSIN',func=pin_types.INPUT),
            Pin(num='10',name='OUTG1',func=pin_types.OPENCOLL),
            Pin(num='11',name='OUTR1',func=pin_types.OPENCOLL),
            Pin(num='12',name='OUTB1',func=pin_types.OPENCOLL),
            Pin(num='13',name='OUTG2',func=pin_types.OPENCOLL),
            Pin(num='14',name='OUTR2',func=pin_types.OPENCOLL),
            Pin(num='15',name='OUTB2',func=pin_types.OPENCOLL),
            Pin(num='16',name='OUTG3',func=pin_types.OPENCOLL),
            Pin(num='17',name='OUTR3',func=pin_types.OPENCOLL),
            Pin(num='18',name='OUTB3',func=pin_types.OPENCOLL),
            Pin(num='2',name='GSSCK',func=pin_types.INPUT),
            Pin(num='21',name='OUTB4',func=pin_types.OPENCOLL),
            Pin(num='22',name='OUTR4',func=pin_types.OPENCOLL),
            Pin(num='23',name='OUTG4',func=pin_types.OPENCOLL),
            Pin(num='24',name='OUTB5',func=pin_types.OPENCOLL),
            Pin(num='25',name='OUTR5',func=pin_types.OPENCOLL),
            Pin(num='26',name='OUTG5',func=pin_types.OPENCOLL),
            Pin(num='27',name='OUTB6',func=pin_types.OPENCOLL),
            Pin(num='28',name='OUTR6',func=pin_types.OPENCOLL),
            Pin(num='29',name='OUTG6',func=pin_types.OPENCOLL),
            Pin(num='3',name='GSLAT',func=pin_types.INPUT),
            Pin(num='30',name='OUTB7',func=pin_types.OPENCOLL),
            Pin(num='31',name='OUTR7',func=pin_types.OPENCOLL),
            Pin(num='32',name='OUTG7',func=pin_types.OPENCOLL),
            Pin(num='33',name='GND',func=pin_types.PWRIN),
            Pin(num='34',name='IREF',func=pin_types.PASSIVE),
            Pin(num='35',name='VCC',func=pin_types.PWRIN),
            Pin(num='36',name='XBLNK',func=pin_types.INPUT),
            Pin(num='37',name='DCSCK',func=pin_types.INPUT),
            Pin(num='38',name='DCSIN',func=pin_types.INPUT),
            Pin(num='39',name='GND',func=pin_types.PASSIVE),
            Pin(num='4',name='GSCKG',func=pin_types.INPUT),
            Pin(num='5',name='GSCKR',func=pin_types.INPUT),
            Pin(num='6',name='GSCKB',func=pin_types.INPUT),
            Pin(num='7',name='OUTG0',func=pin_types.OPENCOLL),
            Pin(num='8',name='OUTR0',func=pin_types.OPENCOLL),
            Pin(num='9',name='OUTB0',func=pin_types.OPENCOLL),
            Pin(num='19',name='GSSOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='DCSOUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLC5951RHA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLC5951RHA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm_ThermalVias'], 'footprint':'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm_ThermalVias', 'keywords':'led driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tlc5951.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nTLC5951RHA\n\nled driver', 'pins':[
            Pin(num='1',name='OUTG3',func=pin_types.OPENCOLL),
            Pin(num='10',name='OUTG4',func=pin_types.OPENCOLL),
            Pin(num='11',name='OUTB5',func=pin_types.OPENCOLL),
            Pin(num='12',name='OUTR5',func=pin_types.OPENCOLL),
            Pin(num='13',name='OUTG5',func=pin_types.OPENCOLL),
            Pin(num='14',name='OUTB6',func=pin_types.OPENCOLL),
            Pin(num='15',name='OUTR6',func=pin_types.OPENCOLL),
            Pin(num='16',name='OUTG6',func=pin_types.OPENCOLL),
            Pin(num='17',name='OUTB7',func=pin_types.OPENCOLL),
            Pin(num='18',name='OUTR7',func=pin_types.OPENCOLL),
            Pin(num='19',name='OUTG7',func=pin_types.OPENCOLL),
            Pin(num='2',name='OUTR3',func=pin_types.OPENCOLL),
            Pin(num='20',name='GND',func=pin_types.PWRIN),
            Pin(num='21',name='IREF',func=pin_types.PASSIVE),
            Pin(num='22',name='VCC',func=pin_types.PWRIN),
            Pin(num='23',name='XBLNK',func=pin_types.INPUT),
            Pin(num='24',name='DCSCK',func=pin_types.INPUT),
            Pin(num='25',name='DCSIN',func=pin_types.INPUT),
            Pin(num='26',name='GSSIN',func=pin_types.INPUT),
            Pin(num='27',name='GSSCK',func=pin_types.INPUT),
            Pin(num='28',name='GSLAT',func=pin_types.INPUT),
            Pin(num='29',name='GSCKG',func=pin_types.INPUT),
            Pin(num='3',name='OUTB3',func=pin_types.OPENCOLL),
            Pin(num='30',name='GSCKR',func=pin_types.INPUT),
            Pin(num='31',name='GSCKB',func=pin_types.INPUT),
            Pin(num='32',name='OUTG0',func=pin_types.OPENCOLL),
            Pin(num='33',name='OUTR0',func=pin_types.OPENCOLL),
            Pin(num='34',name='OUTB0',func=pin_types.OPENCOLL),
            Pin(num='35',name='OUTG1',func=pin_types.OPENCOLL),
            Pin(num='36',name='OUTR1',func=pin_types.OPENCOLL),
            Pin(num='37',name='OUTB1',func=pin_types.OPENCOLL),
            Pin(num='38',name='OUTG2',func=pin_types.OPENCOLL),
            Pin(num='39',name='OUTR2',func=pin_types.OPENCOLL),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT),
            Pin(num='40',name='OUTB2',func=pin_types.OPENCOLL),
            Pin(num='41',name='GND',func=pin_types.PASSIVE),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT),
            Pin(num='8',name='OUTB4',func=pin_types.OPENCOLL),
            Pin(num='9',name='OUTR4',func=pin_types.OPENCOLL),
            Pin(num='5',name='GSSOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='DCSOUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLC5957RTQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLC5957RTQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_8x8mm_P0.5mm_EP5.6x5.6mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_8x8mm_P0.5mm_EP5.6x5.6mm_ThermalVias', 'keywords':'led driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tlc5957.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nTLC5957RTQ\n\nled driver', 'pins':[
            Pin(num='1',name='IREF',func=pin_types.PASSIVE),
            Pin(num='10',name='OUTB0',func=pin_types.OPENCOLL),
            Pin(num='11',name='OUTR1',func=pin_types.OPENCOLL),
            Pin(num='12',name='OUTG1',func=pin_types.OPENCOLL),
            Pin(num='13',name='OUTB1',func=pin_types.OPENCOLL),
            Pin(num='14',name='OUTR2',func=pin_types.OPENCOLL),
            Pin(num='15',name='OUTG2',func=pin_types.OPENCOLL),
            Pin(num='16',name='OUTB2',func=pin_types.OPENCOLL),
            Pin(num='17',name='OUTR3',func=pin_types.OPENCOLL),
            Pin(num='18',name='OUTG3',func=pin_types.OPENCOLL),
            Pin(num='19',name='OUTB3',func=pin_types.OPENCOLL),
            Pin(num='2',name='OUTR14',func=pin_types.OPENCOLL),
            Pin(num='20',name='OUTR4',func=pin_types.OPENCOLL),
            Pin(num='21',name='OUTG4',func=pin_types.OPENCOLL),
            Pin(num='22',name='OUTB4',func=pin_types.OPENCOLL),
            Pin(num='23',name='OUTR5',func=pin_types.OPENCOLL),
            Pin(num='24',name='OUTG5',func=pin_types.OPENCOLL),
            Pin(num='25',name='OUTB5',func=pin_types.OPENCOLL),
            Pin(num='26',name='SIN',func=pin_types.INPUT),
            Pin(num='27',name='LAT',func=pin_types.INPUT),
            Pin(num='28',name='SCLK',func=pin_types.INPUT),
            Pin(num='29',name='GCLK',func=pin_types.INPUT),
            Pin(num='3',name='OUTG14',func=pin_types.OPENCOLL),
            Pin(num='30',name='OUTR6',func=pin_types.OPENCOLL),
            Pin(num='31',name='OUTG6',func=pin_types.OPENCOLL),
            Pin(num='32',name='OUTB6',func=pin_types.OPENCOLL),
            Pin(num='33',name='OUTR7',func=pin_types.OPENCOLL),
            Pin(num='34',name='OUTG7',func=pin_types.OPENCOLL),
            Pin(num='35',name='OUTB7',func=pin_types.OPENCOLL),
            Pin(num='36',name='OUTR8',func=pin_types.OPENCOLL),
            Pin(num='37',name='OUTG8',func=pin_types.OPENCOLL),
            Pin(num='38',name='OUTB8',func=pin_types.OPENCOLL),
            Pin(num='39',name='OUTR9',func=pin_types.OPENCOLL),
            Pin(num='4',name='OUTB14',func=pin_types.OPENCOLL),
            Pin(num='40',name='OUTG9',func=pin_types.OPENCOLL),
            Pin(num='41',name='OUTB9',func=pin_types.OPENCOLL),
            Pin(num='43',name='VCC',func=pin_types.PWRIN),
            Pin(num='44',name='OUTR10',func=pin_types.OPENCOLL),
            Pin(num='45',name='OUTG10',func=pin_types.OPENCOLL),
            Pin(num='46',name='OUTB10',func=pin_types.OPENCOLL),
            Pin(num='47',name='OUTR11',func=pin_types.OPENCOLL),
            Pin(num='48',name='OUTG11',func=pin_types.OPENCOLL),
            Pin(num='49',name='OUTB11',func=pin_types.OPENCOLL),
            Pin(num='5',name='OUTR15',func=pin_types.OPENCOLL),
            Pin(num='50',name='OUTR12',func=pin_types.OPENCOLL),
            Pin(num='51',name='OUTG12',func=pin_types.OPENCOLL),
            Pin(num='52',name='OUTB12',func=pin_types.OPENCOLL),
            Pin(num='53',name='OUTR13',func=pin_types.OPENCOLL),
            Pin(num='54',name='OUTG13',func=pin_types.OPENCOLL),
            Pin(num='55',name='OUTB13',func=pin_types.OPENCOLL),
            Pin(num='56',name='IREFGND',func=pin_types.PWRIN),
            Pin(num='57',name='GND',func=pin_types.PWRIN),
            Pin(num='6',name='OUTG15',func=pin_types.OPENCOLL),
            Pin(num='7',name='OUTB15',func=pin_types.OPENCOLL),
            Pin(num='8',name='OUTR0',func=pin_types.OPENCOLL),
            Pin(num='9',name='OUTG0',func=pin_types.OPENCOLL),
            Pin(num='42',name='SOUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLC5971PWP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLC5971PWP'}), 'ref_prefix':'U', 'fplist':['Package_SO:HTSSOP-20-1EP_4.4x6.5mm_P0.65mm_EP3.4x6.5mm_Mask2.75x3.43mm_ThermalVias'], 'footprint':'Package_SO:HTSSOP-20-1EP_4.4x6.5mm_P0.65mm_EP3.4x6.5mm_Mask2.75x3.43mm_ThermalVias', 'keywords':'led driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tlc5971.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nTLC5971PWP\n\nled driver', 'pins':[
            Pin(num='10',name='SCKI',func=pin_types.INPUT),
            Pin(num='13',name='OUTR2',func=pin_types.OPENCOLL),
            Pin(num='14',name='OUTG2',func=pin_types.OPENCOLL),
            Pin(num='15',name='OUTB2',func=pin_types.OPENCOLL),
            Pin(num='16',name='OUTR3',func=pin_types.OPENCOLL),
            Pin(num='17',name='OUTG3',func=pin_types.OPENCOLL),
            Pin(num='18',name='OUTB3',func=pin_types.OPENCOLL),
            Pin(num='19',name='VCC',func=pin_types.PWRIN),
            Pin(num='2',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VREG',func=pin_types.PASSIVE),
            Pin(num='21',name='GND',func=pin_types.PASSIVE),
            Pin(num='3',name='OUTR0',func=pin_types.OPENCOLL),
            Pin(num='4',name='OUTG0',func=pin_types.OPENCOLL),
            Pin(num='5',name='OUTB0',func=pin_types.OPENCOLL),
            Pin(num='6',name='OUTR1',func=pin_types.OPENCOLL),
            Pin(num='7',name='OUTG1',func=pin_types.OPENCOLL),
            Pin(num='8',name='OUTB1',func=pin_types.OPENCOLL),
            Pin(num='9',name='SDTI',func=pin_types.INPUT),
            Pin(num='1',name='IREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='SCKO',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SDTO',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLC5971RGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLC5971RGE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGE0024H_VQFN-24-1EP_4x4mm_P0.5mm_EP2.7x2.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:Texas_RGE0024H_VQFN-24-1EP_4x4mm_P0.5mm_EP2.7x2.7mm_ThermalVias', 'keywords':'led driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tlc5971.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nTLC5971RGE\n\nled driver', 'pins':[
            Pin(num='1',name='SDTI',func=pin_types.INPUT),
            Pin(num='10',name='OUTR3',func=pin_types.OPENCOLL),
            Pin(num='11',name='OUTG3',func=pin_types.OPENCOLL),
            Pin(num='12',name='OUTB3',func=pin_types.OPENCOLL),
            Pin(num='13',name='VCC',func=pin_types.PWRIN),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT),
            Pin(num='18',name='GND',func=pin_types.PWRIN),
            Pin(num='19',name='OUTR0',func=pin_types.OPENCOLL),
            Pin(num='2',name='SCKI',func=pin_types.INPUT),
            Pin(num='20',name='OUTG0',func=pin_types.OPENCOLL),
            Pin(num='21',name='OUTB0',func=pin_types.OPENCOLL),
            Pin(num='22',name='OUTR1',func=pin_types.OPENCOLL),
            Pin(num='23',name='OUTG1',func=pin_types.OPENCOLL),
            Pin(num='24',name='OUTB1',func=pin_types.OPENCOLL),
            Pin(num='25',name='GND',func=pin_types.PASSIVE),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='SDTO',func=pin_types.OUTPUT),
            Pin(num='7',name='OUTR2',func=pin_types.OPENCOLL),
            Pin(num='8',name='OUTG2',func=pin_types.OPENCOLL),
            Pin(num='9',name='OUTB2',func=pin_types.OPENCOLL),
            Pin(num='15',name='VREG',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='IREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='SCKO',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLC5973', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLC5973'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'LED current driver 12bit PWM', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tlc5973.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nTLC5973\n\nLED current driver 12bit PWM', 'pins':[
            Pin(num='1',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IREF',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPS61165DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPS61165DBV'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'led backlight display driver', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tps61165.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nTPS61165DBV\n\nled backlight display driver', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SW',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='COMP',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='FB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPS92692PWP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPS92692PWP'}), 'ref_prefix':'U', 'fplist':['Package_SO:HTSSOP-20-1EP_4.4x6.5mm_P0.65mm_EP3.4x6.5mm_Mask2.4x3.7mm'], 'footprint':'Package_SO:HTSSOP-20-1EP_4.4x6.5mm_P0.65mm_EP3.4x6.5mm_Mask2.4x3.7mm', 'keywords':'LED Driver Buck Boost Sepic Flyback PWM Dimming', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tps92692-q1.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nTPS92692PWP\n\nLED Driver Buck Boost Sepic Flyback PWM Dimming', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DIM/PWM',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='RAMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='PDRV',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='CSN',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='CSP',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='OV',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SLOPE',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='IS',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='GATE',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VREF',func=pin_types.PWROUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWROUT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~{FLT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='SS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='DM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='RT',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='COMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IMON',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='IADJ',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'WS2811', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'WS2811'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'PWM LED driver', 'description':'', 'datasheet':'https://cdn-shop.adafruit.com/datasheets/WS2811.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nWS2811\n\nPWM LED driver', 'pins':[
            Pin(num='1',name='OUTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='OUTG',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DO',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SET',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'iC-HTG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'iC-HTG'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:HVQFN-24-1EP_4x4mm_P0.5mm_EP2.5x2.5mm'], 'footprint':'Package_DFN_QFN:HVQFN-24-1EP_4x4mm_P0.5mm_EP2.5x2.5mm', 'keywords':'ichaus continous wave monitoring adc', 'description':'', 'datasheet':'https://www.ichaus.de/product/ic-htg/#documents', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\niC-HTG\n\nichaus continous wave monitoring adc', 'pins':[
            Pin(num='10',name='MCH',func=pin_types.INPUT),
            Pin(num='11',name='MCL',func=pin_types.INPUT),
            Pin(num='12',name='MOD',func=pin_types.INPUT),
            Pin(num='13',name='CI',func=pin_types.INPUT),
            Pin(num='14',name='CIL',func=pin_types.INPUT),
            Pin(num='17',name='VBL',func=pin_types.PWRIN),
            Pin(num='18',name='MD',func=pin_types.INPUT),
            Pin(num='19',name='MR',func=pin_types.INPUT),
            Pin(num='20',name='GND',func=pin_types.PWRIN),
            Pin(num='21',name='DCO',func=pin_types.PASSIVE),
            Pin(num='24',name='VB',func=pin_types.PWRIN),
            Pin(num='4',name='ID',func=pin_types.INPUT),
            Pin(num='5',name='EC',func=pin_types.INPUT),
            Pin(num='8',name='MISO/SDA',func=pin_types.BIDIR),
            Pin(num='9',name='ANIN',func=pin_types.BIDIR),
            Pin(num='1',name='~{CHK}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='VRN',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VRP',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{STBY}',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='INS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~{CS}/A1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='MOSI/A0',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='SCLK/SCL',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CH455H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH455H'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-18_W7.62mm', 'Package_SO:SOP-18_7.495x11.515mm_P1.27mm'], 'footprint':'Package_DIP:DIP-18_W7.62mm', 'keywords':'WCH Nixie I2C', 'description':'', 'datasheet':'https://www.wch-ic.com/products/CH455.html', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nCH455H\n\nWCH Nixie I2C', 'pins':[
            Pin(num='1',name='DIG0',func=pin_types.OUTPUT),
            Pin(num='10',name='SEG1',func=pin_types.TRISTATE),
            Pin(num='11',name='VCC',func=pin_types.PWRIN),
            Pin(num='12',name='SEG2',func=pin_types.TRISTATE),
            Pin(num='13',name='SEG3',func=pin_types.TRISTATE),
            Pin(num='14',name='SEG4',func=pin_types.TRISTATE),
            Pin(num='15',name='SEG5',func=pin_types.TRISTATE),
            Pin(num='16',name='SEG6',func=pin_types.TRISTATE),
            Pin(num='17',name='SEG7',func=pin_types.TRISTATE),
            Pin(num='2',name='SCL',func=pin_types.INPUT),
            Pin(num='3',name='SDA',func=pin_types.BIDIR),
            Pin(num='4',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='DIG1',func=pin_types.OUTPUT),
            Pin(num='6',name='DIG2',func=pin_types.OUTPUT),
            Pin(num='7',name='DIG3',func=pin_types.OUTPUT),
            Pin(num='9',name='SEG0',func=pin_types.TRISTATE),
            Pin(num='18',name='~{INT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='ISET',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HV9922N8-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HV9922N8-G'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-89-3', 'Package_TO_SOT_SMD:SOT-89-3'], 'footprint':'Package_TO_SOT_SMD:SOT-89-3', 'keywords':'CC LED Driver High Voltage', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005311A.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nHV9922N8-G\n\nCC LED Driver High Voltage', 'pins':[
            Pin(num='1',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HV9923N8-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HV9923N8-G'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-89-3', 'Package_TO_SOT_SMD:SOT-89-3', 'Package_TO_SOT_SMD:SOT-89-3'], 'footprint':'Package_TO_SOT_SMD:SOT-89-3', 'keywords':'CC LED Driver High Voltage', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005311A.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nHV9923N8-G\n\nCC LED Driver High Voltage', 'pins':[
            Pin(num='1',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS31FL3216A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS31FL3216A'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.4mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.4mm_EP2.4x2.4mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.4mm_EP2.4x2.4mm', 'keywords':'led pwm audio', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/IS31FL3216A.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nIS31FL3216A\n\nled pwm audio', 'pins':[
            Pin(num='1',name='CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='OUT7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='OUT8',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='GPIO9/OUT9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GPIO10/OUT10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GPIO11/OUT11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GPIO12/OUT12',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GPIO13/OUT13',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GPIO14/OUT14',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GPIO15/OUT15',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GPIO16/OUT16',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='~{INTB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='~{SDB}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='AD',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='C_FILT',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='R_EXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='OUT2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='OUT3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='OUT4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='OUT5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='OUT6',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS31FL3236A-TQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS31FL3236A-TQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP4.11x4.11mm', 'Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP4.11x4.11mm'], 'footprint':'Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP4.11x4.11mm', 'keywords':'led matrix pwm', 'description':'', 'datasheet':'https://www.lumissil.com/assets/pdf/core/IS31FL3236A_DS.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nIS31FL3236A-TQ\n\nled matrix pwm', 'pins':[
            Pin(num='1',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='OUT11',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='OUT12',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='OUT13',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='OUT14',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='OUT15',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='OUT16',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OUT17',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='OUT18',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='OUT19',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='OUT20',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='OUT21',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='OUT22',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='OUT23',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OUT24',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='OUT25',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='OUT26',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='OUT27',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='OUT28',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='OUT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='OUT29',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OUT30',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='OUT31',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='OUT32',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='OUT33',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='OUT34',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='OUT35',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='OUT36',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='~{SDB}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='AD',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='R_EXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='SDA',func=pin_types.OPENCOLL,unit=1),
            Pin(num='46',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='OUT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OUT8',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='OUT9',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='OUT10',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT3465A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT3465A'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-6', 'keywords':'Switching LED driver', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/3465fa.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLT3465A\n\nSwitching LED driver', 'pins':[
            Pin(num='1',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SW',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT3755xMSE-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT3755xMSE-2'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-16-1EP_3x4mm_P0.5mm_EP1.65x2.85mm', 'Package_SO:MSOP-16-1EP_3x4mm_P0.5mm_EP1.65x2.85mm'], 'footprint':'Package_SO:MSOP-16-1EP_3x4mm_P0.5mm_EP1.65x2.85mm', 'keywords':'Boost Buck Buck-Boost SEPIC Flyback', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/37551fd.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLT3755xMSE-2\n\nBoost Buck Buck-Boost SEPIC Flyback', 'pins':[
            Pin(num='1',name='PWMOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='SS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='RT',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{SHDN}/UVLO',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='INTVCC',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GATE',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='ISN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='ISP',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VC',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VREF',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{OPENLED}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT3755xUD-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT3755xUD-2'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.45x1.45mm', 'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.45x1.45mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.45x1.45mm', 'keywords':'Boost Buck Buck-Boost SEPIC Flyback', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/37551fd.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLT3755xUD-2\n\nBoost Buck Buck-Boost SEPIC Flyback', 'pins':[
            Pin(num='1',name='VREF',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GATE',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='PWMOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='ISN',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='ISP',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VC',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{OPENLED}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SS',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{SHDN}/UVLO',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='INTVCC',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='SENSE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT3756xMSE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT3756xMSE'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-16-1EP_3x4mm_P0.5mm_EP1.65x2.85mm', 'Package_SO:MSOP-16-1EP_3x4mm_P0.5mm_EP1.65x2.85mm', 'Package_SO:MSOP-16-1EP_3x4mm_P0.5mm_EP1.65x2.85mm'], 'footprint':'Package_SO:MSOP-16-1EP_3x4mm_P0.5mm_EP1.65x2.85mm', 'keywords':'Boost Buck Buck-Boost SEPIC Flyback', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/375612fb.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLT3756xMSE\n\nBoost Buck Buck-Boost SEPIC Flyback', 'pins':[
            Pin(num='1',name='PWMOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='SS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='RT',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{SHDN}/UVLO',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='INTVCC',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GATE',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='ISN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='ISP',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VC',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VREF',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{OPENLED}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT3756xMSE-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT3756xMSE-1'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-16-1EP_3x4mm_P0.5mm_EP1.65x2.85mm', 'Package_SO:MSOP-16-1EP_3x4mm_P0.5mm_EP1.65x2.85mm'], 'footprint':'Package_SO:MSOP-16-1EP_3x4mm_P0.5mm_EP1.65x2.85mm', 'keywords':'Boost Buck Buck-Boost SEPIC Flyback', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/375612fb.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLT3756xMSE-1\n\nBoost Buck Buck-Boost SEPIC Flyback', 'pins':[
            Pin(num='1',name='PWMOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='SS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='RT',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{SHDN}/UVLO',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='INTVCC',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GATE',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='ISN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='ISP',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VC',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VREF',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SYNC',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT3756xMSE-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT3756xMSE-2'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-16-1EP_3x4mm_P0.5mm_EP1.65x2.85mm', 'Package_SO:MSOP-16-1EP_3x4mm_P0.5mm_EP1.65x2.85mm', 'Package_SO:MSOP-16-1EP_3x4mm_P0.5mm_EP1.65x2.85mm', 'Package_SO:MSOP-16-1EP_3x4mm_P0.5mm_EP1.65x2.85mm'], 'footprint':'Package_SO:MSOP-16-1EP_3x4mm_P0.5mm_EP1.65x2.85mm', 'keywords':'Boost Buck Buck-Boost SEPIC Flyback', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/375612fb.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLT3756xMSE-2\n\nBoost Buck Buck-Boost SEPIC Flyback', 'pins':[
            Pin(num='1',name='PWMOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='SS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='RT',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{SHDN}/UVLO',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='INTVCC',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GATE',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='ISN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='ISP',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VC',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VREF',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{OPENLED}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT3756xUD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT3756xUD'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.45x1.45mm', 'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.45x1.45mm', 'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.45x1.45mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.45x1.45mm', 'keywords':'Boost Buck Buck-Boost SEPIC Flyback', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/375612fb.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLT3756xUD\n\nBoost Buck Buck-Boost SEPIC Flyback', 'pins':[
            Pin(num='1',name='VREF',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GATE',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='PWMOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='ISN',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='ISP',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VC',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{OPENLED}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SS',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{SHDN}/UVLO',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='INTVCC',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='SENSE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT3756xUD-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT3756xUD-1'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.45x1.45mm', 'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.45x1.45mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.45x1.45mm', 'keywords':'Boost Buck Buck-Boost SEPIC Flyback', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/375612fb.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLT3756xUD-1\n\nBoost Buck Buck-Boost SEPIC Flyback', 'pins':[
            Pin(num='1',name='VREF',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GATE',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='PWMOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='ISN',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='ISP',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VC',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SS',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SHDN/UVLO',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='INTVCC',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='SENSE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT3756xUD-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT3756xUD-2'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.45x1.45mm', 'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.45x1.45mm', 'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.45x1.45mm', 'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.45x1.45mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.45x1.45mm', 'keywords':'Boost Buck Buck-Boost SEPIC Flyback', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/375612fb.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nLT3756xUD-2\n\nBoost Buck Buck-Boost SEPIC Flyback', 'pins':[
            Pin(num='1',name='VREF',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GATE',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='PWMOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='ISN',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='ISP',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VC',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{OPENLED}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SS',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{SHDN}/UVLO',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='INTVCC',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='SENSE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX7221xRG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX7221xRG'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-24_W7.62mm', 'Package_DIP:DIP-24_W7.62mm'], 'footprint':'Package_DIP:DIP-24_W7.62mm', 'keywords':'spi qspi microwire', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX7219-MAX7221.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nMAX7221xRG\n\nspi qspi microwire', 'pins':[
            Pin(num='1',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DIG_5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='DIG_1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SEG_A',func=pin_types.OPENEMIT,unit=1),
            Pin(num='15',name='SEG_F',func=pin_types.OPENEMIT,unit=1),
            Pin(num='16',name='SEG_B',func=pin_types.OPENEMIT,unit=1),
            Pin(num='17',name='SEG_G',func=pin_types.OPENEMIT,unit=1),
            Pin(num='18',name='ISET',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='DIG_0',func=pin_types.OPENCOLL,unit=1),
            Pin(num='20',name='SEG_C',func=pin_types.OPENEMIT,unit=1),
            Pin(num='21',name='SEG_E',func=pin_types.OPENEMIT,unit=1),
            Pin(num='22',name='SEG_DP',func=pin_types.OPENEMIT,unit=1),
            Pin(num='23',name='SEG_D',func=pin_types.OPENEMIT,unit=1),
            Pin(num='24',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='DIG_4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DIG_6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='DIG_2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='DIG_3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='DIG_7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MPQ3362GJ-AEC1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MPQ3362GJ-AEC1'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-8', 'Package_TO_SOT_SMD:TSOT-23-8'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-8', 'keywords':'LED driver AEC AEC1-Q100', 'description':'', 'datasheet':'https://www.monolithicpower.com/en/documentview/productdocument/index/version/2/document_type/Datasheet/lang/en/sku/MPQ3362GJ-AEC1/document_id/9116/', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nMPQ3362GJ-AEC1\n\nLED driver AEC AEC1-Q100', 'pins':[
            Pin(num='1',name='SW',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='COMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='OSC',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='FB',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='OVP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLC5917', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLC5917'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'LED Constant-Current Driver', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tlc5917.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nTLC5917\n\nLED Constant-Current Driver', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{OUT5}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='~{OUT6}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='~{OUT7}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='~{OE}(ED2)',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='R-EXT',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='LE(ED1)',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~{OUT0}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='~{OUT1}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='~{OUT2}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='~{OUT3}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='~{OUT4}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLC5951RTA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLC5951RTA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm_ThermalVias', 'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm_ThermalVias'], 'footprint':'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm_ThermalVias', 'keywords':'led driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tlc5951.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_LED.kicad_sym\nTLC5951RTA\n\nled driver', 'pins':[
            Pin(num='1',name='OUTG3',func=pin_types.OPENCOLL),
            Pin(num='10',name='OUTG4',func=pin_types.OPENCOLL),
            Pin(num='11',name='OUTB5',func=pin_types.OPENCOLL),
            Pin(num='12',name='OUTR5',func=pin_types.OPENCOLL),
            Pin(num='13',name='OUTG5',func=pin_types.OPENCOLL),
            Pin(num='14',name='OUTB6',func=pin_types.OPENCOLL),
            Pin(num='15',name='OUTR6',func=pin_types.OPENCOLL),
            Pin(num='16',name='OUTG6',func=pin_types.OPENCOLL),
            Pin(num='17',name='OUTB7',func=pin_types.OPENCOLL),
            Pin(num='18',name='OUTR7',func=pin_types.OPENCOLL),
            Pin(num='19',name='OUTG7',func=pin_types.OPENCOLL),
            Pin(num='2',name='OUTR3',func=pin_types.OPENCOLL),
            Pin(num='20',name='GND',func=pin_types.PWRIN),
            Pin(num='21',name='IREF',func=pin_types.PASSIVE),
            Pin(num='22',name='VCC',func=pin_types.PWRIN),
            Pin(num='23',name='XBLNK',func=pin_types.INPUT),
            Pin(num='24',name='DCSCK',func=pin_types.INPUT),
            Pin(num='25',name='DCSIN',func=pin_types.INPUT),
            Pin(num='26',name='GSSIN',func=pin_types.INPUT),
            Pin(num='27',name='GSSCK',func=pin_types.INPUT),
            Pin(num='28',name='GSLAT',func=pin_types.INPUT),
            Pin(num='29',name='GSCKG',func=pin_types.INPUT),
            Pin(num='3',name='OUTB3',func=pin_types.OPENCOLL),
            Pin(num='30',name='GSCKR',func=pin_types.INPUT),
            Pin(num='31',name='GSCKB',func=pin_types.INPUT),
            Pin(num='32',name='OUTG0',func=pin_types.OPENCOLL),
            Pin(num='33',name='OUTR0',func=pin_types.OPENCOLL),
            Pin(num='34',name='OUTB0',func=pin_types.OPENCOLL),
            Pin(num='35',name='OUTG1',func=pin_types.OPENCOLL),
            Pin(num='36',name='OUTR1',func=pin_types.OPENCOLL),
            Pin(num='37',name='OUTB1',func=pin_types.OPENCOLL),
            Pin(num='38',name='OUTG2',func=pin_types.OPENCOLL),
            Pin(num='39',name='OUTR2',func=pin_types.OPENCOLL),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT),
            Pin(num='40',name='OUTB2',func=pin_types.OPENCOLL),
            Pin(num='41',name='GND',func=pin_types.PASSIVE),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT),
            Pin(num='8',name='OUTB4',func=pin_types.OPENCOLL),
            Pin(num='9',name='OUTR4',func=pin_types.OPENCOLL),
            Pin(num='5',name='GSSOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='DCSOUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] })])